@@ -111,7 +111,7 @@
     ("Zenkaku to Ascii" . "$BA43Q1Q?t$r(B ASCII $B$KJQ49(B")
     ("Count Jisyo Candidates" . "$B<-=qCf$N8uJd?t$r?t$($k(B")
     ("Save Jisyo" . "$B<-=q$rJ]B8$9$k(B")
-    ("Undo Kakutei" . "$B3NDj$r<h$j>C$9(B ($B%"%s%I%%!<(B)")
+    ("Undo Kakutei" . "$B3NDj$r<h$j>C$9(B ($B%"%s%I%%(B)")
     ("Restart SKK" . "SKK $B$N:F5/F0(B")
     ("Version" . "SKK $B$N%P!<%8%g%s(B")
     ("Daredevil SKK Menu" . "Daredevil SKK $B%a%K%e!<(B")
