@@ -4,9 +4,9 @@
 ;; Copyright (C) 1993-2000 Free Software Foundation, Inc.
 
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-macs.el,v 1.158 2010/11/13 11:47:14 skk-cvs Exp $
+;; Version: $Id: skk-macs.el,v 1.160 2010/12/16 11:16:08 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/11/13 11:47:14 $
+;; Last Modified: $Date: 2010/12/16 11:16:08 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -589,6 +589,10 @@ BUFFER defaults to the current buffer."
 	    force)
     (skk-cursor-set-1 color)))
 
+(defsubst skk-inline-hide ()
+  (when skk-inline-overlays
+    (skk-inline-hide-1)))
+
 (defun skk-cursor-off ()
   (unless (skk-color-cursor-display-p)
     (setq skk-use-color-cursor nil))
@@ -936,15 +940,21 @@ BUFFER defaults to the current buffer."
 	      skk-last-henkan-data)))))
 
 (defun skk-find-coding-system (code)
+  "CODE $B$,!"(BEmacs $B$,2r<a$9$k(B coding-system $B%7%s%\%kI=8=$G$"$l$P$=$N$^$^JV$7!"(B
+$BJ8;zNs$G$"$l$P(B $BO"A[%j%9%H(B `skk-coding-system-alist' $B$rMQ$$$F%7%s%\%kI=8=$XJQ49$9$k!#(B
+$B$3$l$i0J30!J(Bnil $B$r4^$`!K$G$"$l$P(B $B%7%s%\%k(B euc-jisx0213 $B$rJV$9!#(B"
   (cond ((and code
-	      (or (and (fboundp 'coding-system-p)
+	      (or (and (fboundp 'coding-system-p) ; GNU Emacs
 		       (coding-system-p code))
-		  (and (fboundp 'find-coding-system)
+		  (and (fboundp 'find-coding-system) ; XEmacs
 		       (symbolp code)
 		       (find-coding-system code))))
 	 code)
-	((and code (stringp code))
+	;;
+	((and code
+	      (stringp code))
 	 (cdr (assoc code skk-coding-system-alist)))
+	;;
 	(t
 	 (cdr (assoc "euc" skk-coding-system-alist)))))
 
